==> variant_json_file_utils-0.1.9.tar.gz: variant_json_file_utils-0.1.9/variant_json_file_utils/json/annotated_match_call/record.py <==
from pydantic import BaseModel, Field
from typing import List, Optional

class Record(BaseModel):
    """Class for the annotated match call record."""
    chromosome: Optional[str] = Field(None, title="The chromosome.")
    start: Optional[int] = Field(None, title="The start coordinate.")
    end: Optional[int] = Field(None, title="The end coordinate.")
    ref: Optional[str] = Field(None, title="The reference.")
    alt: Optional[str] = Field(None, title="The alternative.")
    sample_name: Optional[str] = Field(None, title="The sample name.")
    alleles: Optional[List[str]] = Field(None, title="The alleles.")
    allele_indices: Optional[List[int]] = Field(None, title="The allele indices.")
    zyg: Optional[str] = Field(None, title="The zygosity.")
    is_phased: Optional[bool] = Field(None, title="Whether the variant is phased.")
    quality: Optional[float] = Field(None, title="The quality.")
    id: Optional[str] = Field(None, title="The variant ID.")
    filters: Optional[List[str]] = Field(None, title="The filters.")
    build: Optional[str] = Field(None, title="The build.")
    total_depth: Optional[int] = Field(None, title="The total depth.")
    alt_depth: Optional[int] = Field(None, title="The alternative depth.")
    ref_depth: Optional[int] = Field(None, title="The reference depth.")
    vaf: Optional[float] = Field(None, title="The variant allele frequency.")
    vaf_alt: Optional[float] = Field(None, title="The variant allele frequency for the alternative allele.")

    # The distance from the previous variant
    distance_1: Optional[int] = Field(None, title="The absolute distance from previous variant")

    # The distance from the following variant
    distance_2: Optional[int] = Field(None, title="The absolute distance from following variant")

    @property
    def vcf(self):
        """Get the variant."""
        return f"{self.chromosome}_{self.start}_{self.end}_{self.ref}_{self.alt}"

==> variant_json_file_utils-0.1.13.tar.gz: variant_json_file_utils-0.1.13/variant_json_file_utils/json/annotated_match_call/record.py <==
from pydantic import BaseModel, Field
from typing import List, Optional

class Record(BaseModel):
    """Class for the annotated match call record."""
    chromosome: Optional[str] = Field(None, title="The chromosome.")
    start: Optional[int] = Field(None, title="The start coordinate.")
    end: Optional[int] = Field(None, title="The end coordinate.")
    fs: Optional[float] = Field(None, title="Phred-scaled p-value using Fisher's exact test to detect strand bias.")
    ref: Optional[str] = Field(None, title="The reference.")
    alt: Optional[str] = Field(None, title="The alternative.")
    sample_name: Optional[str] = Field(None, title="The sample name.")
    alleles: Optional[List[str]] = Field(None, title="The alleles.")
    allele_indices: Optional[List[int]] = Field(None, title="The allele indices.")
    zygosity: Optional[str] = Field(None, title="The zygosity.")
    is_phased: Optional[bool] = Field(None, title="Whether the variant is phased.")
    quality: Optional[float] = Field(None, title="The quality.")
    id: Optional[str] = Field(None, title="The variant ID.")
    filters: Optional[List[str]] = Field(None, title="The filters.")
    build: Optional[str] = Field(None, title="The build.")
    total_depth: Optional[int] = Field(None, title="The total depth.")
    alt_depth: Optional[int] = Field(None, title="The alternative depth.")
    ref_depth: Optional[int] = Field(None, title="The reference depth.")
    vaf: Optional[float] = Field(None, title="The variant allele frequency.")
    vaf_alt: Optional[float] = Field(None, title="The variant allele frequency for the alternative allele.")

    # The distance from the previous variant
    distance_1: Optional[int] = Field(None, title="The absolute distance from previous variant")

    # The distance from the following variant
    distance_2: Optional[int] = Field(None, title="The absolute distance from following variant")

    @property
    def vcf(self):
        """Get the variant."""
        return f"{self.chromosome}_{self.start}_{self.end}_{self.ref}_{self.alt}"
